@@ -69,6 +69,7 @@
 #include "dods-limits.h"
 #include "debug.h"
 #include "InternalErr.h"
+#include "DapIndent.h"
 
 using std::cerr;
 using std::endl;
@@ -198,7 +199,7 @@ Int64::ops(BaseType *b, int op)
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
 
     // Get the second arg's value.
-    if (!b->read_p() && !b->read())
+    if (!b || !(b->read_p() || b->read())) 
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
 
     return d4_ops(b, op);
