@@ -50,6 +50,7 @@
 #include "dods-limits.h"
 #include "debug.h"
 #include "InternalErr.h"
+#include "DapIndent.h"
 
 using std::cerr;
 using std::endl;
@@ -231,6 +232,40 @@ UInt64::d4_ops(BaseType *b, int op)
     }
 }
 
+
+
+/** @brief DAP4 to DAP2 transform
+ *
+ * For the current BaseType, return a DAP2 'copy' of the variable.
+ *
+ * @note For most DAP4 types, in this implementation of DAP2 the corresponding
+ * DAP4 type is the same. The different types are Sequences (which are D4Sequences
+ * in the DAP4 implementation), Grids (which are coverages) and Arrays (which use
+ * shared dimensions).
+ *
+ * @param root The root group that should hold this new variable. Add Group-level
+ * stuff here (e.g., D4Dimensions).
+ * @param container Add the new variable to this container.
+ *
+ * @return A pointer to the transformed variable
+ */
+std::vector<BaseType *> *
+UInt64::transform_to_dap2(AttrTable *)
+{
+#if 0
+    BaseType *dest = this->ptr_duplicate();
+    // convert the d4 attributes to a dap2 attribute table.
+    AttrTable *attrs = this->attributes()->get_AttrTable();
+    attrs->set_name(name());
+    dest->set_attr_table(*attrs);
+    dest->set_is_dap4(false);
+    // attrs->print(cerr,"",true);
+    return dest;
+#endif
+
+    return NULL;
+}
+
 /** @brief dumps information about this object
  *
  * Displays the pointer value of this instance and information about this
